(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@herbis/ngx-modal'), require('@angular/common')) :
	typeof define === 'function' && define.amd ? define(['exports', '@angular/core', '@herbis/ngx-modal', '@angular/common'], factory) :
	(factory((global.ngx = global.ngx || {}, global.ngx.bootstrap = global.ngx.bootstrap || {}, global.ngx.bootstrap.feedback = global.ngx.bootstrap.feedback || {}),global.ng.core,global.ngx.modal,global.ng.common));
}(this, (function (exports,_angular_core,_herbis_ngxModal,_angular_common) { 'use strict';

var FeedbackService = (function () {
    function FeedbackService() {
    }
    /**
     * Clear all screenshots.
     */
    FeedbackService.prototype.clearScreenshots = function () {
        if (this.screenshotComponent) {
            this.screenshotComponent.clearScreenshots();
        }
    };
    /**
     * Destroy screenshot canvas.
     */
    FeedbackService.prototype.destroyCanvas = function () {
        this.screenshotComponent.destroyCanvas();
    };
    /**
     * Get all screenshots.
     * @return {Array} the screenshots.
     */
    FeedbackService.prototype.getScreenshots = function () {
        if (this.screenshotComponent) {
            return this.screenshotComponent.screenshots;
        }
        else {
            return [];
        }
    };
    /**
     * Hide the feedback modal.
     */
    FeedbackService.prototype.hideFeedbackModal = function () {
        this.modalComponent.closeModal();
    };
    /**
     * Hide send feedback button.
     */
    FeedbackService.prototype.hideSendFeedbackButton = function () {
        this.buttonComponent.isHidden = true;
    };
    /**
     * Lock take screenshot buttons.
     */
    FeedbackService.prototype.lockTakeScreenshotButtons = function () {
        this.buttonComponent.isLoading = true;
    };
    /**
     * Unlock take screenshot buttons.
     */
    FeedbackService.prototype.unlockTakeScreenshotButtons = function () {
        this.buttonComponent.isLoading = false;
    };
    /**
     * Show feedback modal.
     */
    FeedbackService.prototype.showFeedbackModal = function () {
        this.modalComponent.openModal();
    };
    /**
     * Show send feedback button.
     */
    FeedbackService.prototype.showSendFeedbackButton = function () {
        this.buttonComponent.isHidden = false;
    };
    /**
     * Set screenshot mode.
     * @param isScreenshotMode whether screenshot mode or not.
     */
    FeedbackService.prototype.setScreenshotMode = function (isScreenshotMode) {
        this.buttonComponent.isScreenshotMode = isScreenshotMode;
    };
    /**
     * Take a screenshot.
     */
    FeedbackService.prototype.takeScreenshot = function () {
        this.screenshotComponent.takeScreenshot();
    };
    return FeedbackService;
}());
FeedbackService.decorators = [
    { type: _angular_core.Injectable },
];
/** @nocollapse */
FeedbackService.ctorParameters = function () { return []; };

/**
 *  Model used for feedback submittions.
 */
var FeedbackModel = (function () {
    function FeedbackModel() {
    }
    return FeedbackModel;
}());

var FeedbackModalComponent = (function () {
    function FeedbackModalComponent(feedback) {
        this.feedback = feedback;
        feedback.modalComponent = this;
    }
    /**
     * Cancel the feedback.
     */
    FeedbackModalComponent.prototype.cancel = function () {
        /* Callback on cancel.*/
        if (this.configuration.onCancel) {
            this.configuration.onCancel();
        }
        this.closeModal();
    };
    /**
     * Close this modal.
     */
    FeedbackModalComponent.prototype.closeModal = function () {
        this.modal.close();
        this.feedback.showSendFeedbackButton();
    };
    /**
     * Open feedback modal.
     */
    FeedbackModalComponent.prototype.openModal = function () {
        this.modal.open();
    };
    /**
     * Submit the form.
     * @param form the form.
     */
    FeedbackModalComponent.prototype.submit = function (form) {
        var feedbackSubmission = new FeedbackModel();
        feedbackSubmission.form = form;
        feedbackSubmission.screenshots = this.feedback.getScreenshots();
        /* Callback on submit validation */
        if (this.configuration.onSubmitValidation) {
            if (!this.configuration.onSubmitValidation(feedbackSubmission)) {
                return; // Do not proceed if validation unsuccessful.
            }
        }
        /* Callback on submit. */
        if (this.configuration.onSubmit) {
            this.configuration.onSubmit(feedbackSubmission);
            this.closeModal();
        }
        else {
            console.warn("No onSubmit callback function configured. It probably should.");
        }
    };
    return FeedbackModalComponent;
}());
FeedbackModalComponent.decorators = [
    { type: _angular_core.Component, args: [{
                selector: "ngx-bootstrap-feedback-modal",
                template: "<modal title=\"{{configuration.feedbackModalTitle ? configuration.feedbackModalTitle : 'Send Feedback'}}\"\n        modalClass=\"{{configuration.feedbackModalClass ? configuration.feedbackModalClass : 'modal-md'}}\"\n        [hideCloseButton]=\"true\"\n        [closeOnEscape]=\"false\"\n        [closeOnOutsideClick]=\"false\">\n  <modal-header></modal-header>\n  <modal-content>\n    <form novalidate #userFeedbackForm>\n      <ng-content></ng-content>\n    </form>\n  </modal-content>\n  <modal-footer>\n    <button [attr.class]=\"configuration.cancelFeedbackButtonClass ? configuration.cancelFeedbackButtonClass : 'btn btn-default'\" data-dismiss=\"modal\" type=\"button\" (click)=\"cancel()\">\n      {{configuration.cancelFeedbackButtonText ? configuration.cancelFeedbackButtonText : \"Cancel\"}}\n    </button>\n    <button [attr.class]=\"configuration.submitFeedbackButtonClass ? configuration.submitFeedbackButtonClass : 'btn btn-primary'\" type=\"button\" (click)=\"submit(userFeedbackForm)\">\n      {{configuration.submitFeedbackButtonText ? configuration.submitFeedbackButtonText : \"Submit\"}}\n    </button>\n  </modal-footer>\n</modal>\n"
            },] },
];
/** @nocollapse */
FeedbackModalComponent.ctorParameters = function () { return [
    { type: FeedbackService, },
]; };
FeedbackModalComponent.propDecorators = {
    'configuration': [{ type: _angular_core.Input },],
    'modal': [{ type: _angular_core.ViewChild, args: [_herbis_ngxModal.Modal,] },],
};

var FeedbackComponent = (function () {
    function FeedbackComponent(feedback) {
        this.feedback = feedback;
        this.isHidden = false;
        this.isLoading = false;
        this.isScreenshotMode = false;
        feedback.buttonComponent = this;
    }
    /**
     * Cancel taking of screenshot.
     */
    FeedbackComponent.prototype.cancelScreenshot = function () {
        if (this.configuration.onCancelScreenshot) {
            this.configuration.onCancelScreenshot();
        }
        this.isScreenshotMode = false;
        this.feedbackModal.openModal();
        this.feedback.destroyCanvas();
    };
    /**
     * Clear screenshots.
     */
    FeedbackComponent.prototype.clearScreenshots = function () {
        this.feedback.clearScreenshots();
    };
    /**
     * Get all screenshots taken.
     * @return {string[]} the screenshots as dataUrls.
     */
    FeedbackComponent.prototype.getScreenshots = function () {
        return this.feedback.getScreenshots();
    };
    /**
     * Open feedback modal.
     */
    FeedbackComponent.prototype.openFeedbackModal = function () {
        if (this.configuration.onOpen) {
            this.configuration.onOpen();
        }
        this.isHidden = true;
        this.feedbackModal.openModal();
    };
    /**
     * Take a screenshot.
     */
    FeedbackComponent.prototype.takeScreenshot = function () {
        this.feedback.takeScreenshot();
    };
    return FeedbackComponent;
}());
FeedbackComponent.decorators = [
    { type: _angular_core.Component, args: [{
                selector: "ngx-bootstrap-feedback",
                styles: ["\n    @keyframes slide {\n          100% { bottom: 0; }\n    }\n    .send-feedback-button {\n        animation: slide 0.3s forwards;\n        bottom: -40px;\n        right: 56px;\n        position: fixed;\n        border-top-left-radius: 10px;\n        border-top-right-radius: 10px;\n        font-size: 12px;\n        text-align: center;\n        z-index: 9001;\n        cursor: pointer;\n        color: #fff;\n        background-color: #8E979F;\n        border: transparent;\n    }"],
                template: "<div [attr.class]=\"configuration.feedbackButtonClass ? configuration.feedbackButtonClass : 'send-feedback-button btn'\"\n     [ngClass]=\"{hidden: isHidden}\"\n     (click)=\"isScreenshotMode ? null : openFeedbackModal()\">\n  <!--- SEND FEEDBACK -->\n  <div *ngIf=\"!isScreenshotMode\">\n    {{configuration.feedbackButtonText ? configuration.feedbackButtonText : \"Send Feedback\"}}\n    <span class=\"glyphicon glyphicon-comment\" aria-hidden=\"true\"></span>\n  </div>\n  <!--- /SEND FEEDBACK -->\n  <!-- SCREENSHOT OPTIONS -->\n  <div *ngIf=\"isScreenshotMode\">\n    <span>Options</span>\n    <div class=\"row\">\n      <div class=\"col-xs-12\">\n        <button [attr.class]=\"'btn-feedback ' + (configuration.takeScreenshotButtonClass ? configuration.takeScreenshotButtonClass : 'btn btn-primary btn-block')\"\n                [attr.disabled]=\"isLoading ? true : null\"\n                (click)=\"takeScreenshot()\"\n                [ngClass]=\"{'loading-icon': configuration.enableLoadingIconClass ? isLoading : false}\">\n          {{configuration.takeScreenshotButtonText ? configuration.takeScreenshotButtonText : \"Take Screenshot\"}}\n        </button>\n      </div>\n    </div>\n    <div class=\"row\">\n      <div class=\"col-xs-12\">\n        <button [attr.class]=\"'btn-feedback ' + (configuration.cancelScreenshotButtonClass ? configuration.cancelScreenshotButtonClass : 'btn btn-default btn-block')\"\n                [attr.disabled]=\"isLoading ? true : null\"\n                (click)=\"cancelScreenshot()\">\n          {{configuration.cancelScreenshotButtonText ? configuration.cancelScreenshotButtonText : \"Cancel\"}}\n        </button>\n      </div>\n    </div>\n  </div>\n  <!-- /SCREENSHOT OPTIONS -->\n</div>\n<ngx-bootstrap-feedback-modal [configuration]=\"configuration\">\n  <ng-content></ng-content>\n</ngx-bootstrap-feedback-modal>\n"
            },] },
];
/** @nocollapse */
FeedbackComponent.ctorParameters = function () { return [
    { type: FeedbackService, },
]; };
FeedbackComponent.propDecorators = {
    'feedbackModal': [{ type: _angular_core.ViewChild, args: [FeedbackModalComponent,] },],
    'configuration': [{ type: _angular_core.Input },],
};

var CANVAS_ID = "feedback-canvas";
var HIGHLIGHT_CLASS = "feedback-highlight";
var FEEDBACK_BTN_CLASS = "btn-feedback";
var DEFAULT_ALLOWED_IMAGE_TYPES = "image/png image/gif image/jpeg";
var DEFAULT_SINGLE_FILE_MAX_SIZE = 2048;
var DEFAULT_MAX_IMAGE_COUNT_ALLOWED = 5;
var FeedbackScreenshotComponent = (function () {
    function FeedbackScreenshotComponent(changeDetection, feedback) {
        this.changeDetection = changeDetection;
        this.feedback = feedback;
        this.screenshots = [];
        this.isDrawing = false;
        feedback.screenshotComponent = this;
    }
    /**
     * Add transparent background to canvas.
     */
    FeedbackScreenshotComponent.prototype.addCanvasAlphaBackground = function () {
        if (!this.canvasContext) {
            throw Error("User feedback context does not exist");
        }
        this.canvasContext.fillStyle = "rgba(102,102,102,0.5)";
        this.canvasContext.fillRect(0, 0, document.body.clientWidth, document.body.clientHeight);
    };
    /**
     * Add a screenshot from local machine.
     * @param event the event of selecting image.
     */
    FeedbackScreenshotComponent.prototype.addScreenshot = function (event) {
        var _this = this;
        var reader = new FileReader();
        var file = event.target.files[0];
        if (file && this.checkIsUploadFileAllowed(file)) {
            reader.onload = function (evnt) {
                _this.screenshots.push(evnt.target.result);
                _this.changeDetection.detectChanges();
                event.target.value = "";
            };
            reader.readAsDataURL(file);
        }
    };
    /**
     * Adjust the drawing according to user movement.
     * @param x the x-axis movement position.
     * @param y the y-axis movement position.
     */
    FeedbackScreenshotComponent.prototype.adjustDrawing = function (x, y) {
        if (this.isDrawing && this.canvasContext) {
            var width = x - this.centerX;
            var height = y - this.centerY;
            this.canvasContext.clearRect(0, 0, document.body.clientWidth, document.body.clientHeight);
            this.addCanvasAlphaBackground();
            this.canvasContext.clearRect(this.centerX, this.centerY, width, height);
            this.redraw();
        }
    };
    /**
     * Clear all screenshots.
     */
    FeedbackScreenshotComponent.prototype.clearScreenshots = function () {
        this.screenshots = [];
        this.changeDetection.detectChanges();
    };
    /**
     * Check if upload file is allowed.
     * @param file the file.
     * @return {boolean} wheter allowed or not.
     */
    FeedbackScreenshotComponent.prototype.checkIsUploadFileAllowed = function (file) {
        this.uploadErrorMessage = null;
        var allowedTypes = this.configuration.allowedImageTypes ?
            this.configuration.allowedImageTypes.split(" ") : DEFAULT_ALLOWED_IMAGE_TYPES.split(" ");
        var maxSingleFileSize = this.configuration.maxSingleFileSize ?
            this.configuration.maxSingleFileSize : DEFAULT_SINGLE_FILE_MAX_SIZE;
        var fileSizeKb = file.size / 1024;
        if (allowedTypes.indexOf(file.type) === -1) {
            var errorMessageTemplate = this.configuration.fileTypeNotAllowedErrorMessage ?
                this.configuration.fileTypeNotAllowedErrorMessage : "File type {type} not allowed.";
            this.uploadErrorMessage = errorMessageTemplate.replace("{type}", file.type);
            return false;
        }
        else if (fileSizeKb > maxSingleFileSize) {
            var errorMessageTemplate = this.configuration.fileSizeTooLargeErrorMessage ?
                this.configuration.fileSizeTooLargeErrorMessage : "File size too large. Max allowed - {maxsize}.";
            /* Format max size string. */
            var maxSizeString = void 0;
            if (fileSizeKb >= 1024) {
                maxSizeString = (maxSingleFileSize / 1024).toFixed(2) + "MB";
            }
            else {
                maxSizeString = maxSingleFileSize.toFixed(2) + "KB";
            }
            /* Format file size string. */
            var fileSizeString = void 0;
            if (fileSizeKb >= 1024) {
                fileSizeString = (fileSizeKb / 1024).toFixed(2) + "MB";
            }
            else {
                fileSizeString = fileSizeKb.toFixed(2) + "KB";
            }
            this.uploadErrorMessage = errorMessageTemplate.replace("{maxsize}", maxSizeString).replace("{size}", fileSizeString);
            return false;
        }
        else {
            return true;
        }
    };
    /**
     * Create a canvas of the page.
     */
    FeedbackScreenshotComponent.prototype.createCanvas = function () {
        if (!this.canvasContext) {
            var canvas = document.createElement("canvas");
            canvas.setAttribute("id", CANVAS_ID);
            canvas.setAttribute("width", String(document.body.clientWidth));
            canvas.setAttribute("height", String(document.body.clientHeight));
            canvas.setAttribute("style", "top: 0");
            document.body.appendChild(canvas);
            this.canvas = canvas;
            this.canvasContext = canvas.getContext("2d");
            this.setupMouseDrawingEvents();
            this.addCanvasAlphaBackground();
        }
    };
    /**
     * Destroy the page canvas.
     */
    FeedbackScreenshotComponent.prototype.destroyCanvas = function () {
        if (this.canvas) {
            this.canvas.remove();
        }
        var highlights = document.getElementsByClassName(HIGHLIGHT_CLASS);
        /* Remove all page highlights. */
        for (var i = 0; i < highlights.length; i++) {
            var highlight = highlights[i];
            highlight.remove();
        }
        this.canvasContext = null;
    };
    /**
     * Enter the screenshot mode.
     */
    FeedbackScreenshotComponent.prototype.enterScreenshotMode = function () {
        if (this.configuration.onEnterTakeScreenshot) {
            this.configuration.onEnterTakeScreenshot();
        }
        this.feedback.buttonComponent.isHidden = false;
        this.feedback.buttonComponent.isScreenshotMode = true;
        this.feedback.modalComponent.closeModal();
        this.createCanvas();
    };
    /**
     * Finish drawing at given position.
     * @param x the x-axis page position to finish at.
     * @param y the y-axis page position to finish at.
     */
    FeedbackScreenshotComponent.prototype.finishDrawing = function (x, y) {
        if (!this.canvasContext) {
            return;
        }
        this.isDrawing = false;
        var width = x - this.centerX;
        var height = y - this.centerY;
        /* If below 10 pixels, consider just a click.*/
        if (width < 10 && height < 10) {
            return;
        }
        /* Fill drawn canvas (highlight) with transparency. */
        this.canvasContext.fillStyle = "rgba(0,0,0,0)";
        this.canvasContext.strokeRect(this.centerX, this.centerY, width, height);
        this.canvasContext.fillRect(this.centerX, this.centerY, width, height);
        /* Remove old element. */
        if (this.highlight) {
            this.highlight.remove();
        }
        /* Create a highlight document element. */
        this.highlight = document.createElement("div");
        this.highlight.setAttribute("style", "position:absolute;top:" + this.centerY
            + "px;left:" + this.centerX
            + "px;width:" + width
            + "px;height:" + height
            + "px;z-index:30000;");
        this.highlight.setAttribute("class", HIGHLIGHT_CLASS);
        this.highlightLeft = this.centerX;
        this.highlightTop = this.centerY;
        this.highlightWidth = width;
        this.highlightHeight = height;
        /* Add highlight div to body. */
        document.body.appendChild(this.highlight);
        this.redraw();
        if (this.configuration.onHighlightDrawn) {
            this.configuration.onHighlightDrawn(this.highlight);
        }
    };
    /**
     * Get the max image count allowed.
     * @return {boolean} the count.
     */
    FeedbackScreenshotComponent.prototype.getMaxImageCount = function () {
        return this.configuration.maxImageCount ? this.configuration.maxImageCount : DEFAULT_MAX_IMAGE_COUNT_ALLOWED;
    };
    /**
     * Check whether max image count has been reached.
     * @return {boolean} whether max image count has been reached.
     */
    FeedbackScreenshotComponent.prototype.isMaxImageCountReached = function () {
        return this.screenshots.length >= this.getMaxImageCount();
    };
    /**
     * Process rendered screenshot.
     * @param canvas the canvas.
     */
    FeedbackScreenshotComponent.prototype.processRenderedScreenshot = function (canvas) {
        var _this = this;
        this.feedback.setScreenshotMode(false);
        this.feedback.showFeedbackModal();
        this.feedback.unlockTakeScreenshotButtons();
        this.feedback.hideSendFeedbackButton();
        this.destroyCanvas();
        canvas.style.width = "100%";
        canvas.style.borderRadius = "12px";
        var sizingCanvas = null;
        /* Handle screenshot highlight case. */
        if (this.configuration.screenshotOnlyHighlighted) {
            /* Create canvas of highlight area.*/
            sizingCanvas = document.createElement("canvas");
            sizingCanvas.width = this.highlightWidth;
            sizingCanvas.height = this.highlightHeight;
            sizingCanvas.getContext("2d").drawImage(canvas, -this.highlightLeft, -this.highlightTop, canvas.width, canvas.height);
        }
        setTimeout(function () {
            var screenshotBase64 = _this.configuration.screenshotOnlyHighlighted ? sizingCanvas.toDataURL() : canvas.toDataURL();
            _this.screenshots.push(screenshotBase64);
            _this.changeDetection.detectChanges();
            document.body.scrollTop = _this.preRenderScrollPosition; // Reset scroll.
            document.body.style["overflow"] = null; // Reset scrolling.
            document.body.classList.remove("wait"); // Set body cursor back to normal.
            _this.canvas.classList.remove("wait"); // Set canvas cursor back to normal.
            if (_this.configuration.onScreenshotTaken) {
                _this.configuration.onScreenshotTaken(screenshotBase64);
            }
        });
    };
    /**
     * Redraw the canvas context.
     */
    FeedbackScreenshotComponent.prototype.redraw = function () {
        if (!this.canvasContext) {
            return;
        }
        var highlights = document.getElementsByClassName(HIGHLIGHT_CLASS);
        for (var i = 0; i < highlights.length; i++) {
            var highlight = highlights[i];
            var style = highlight.getAttribute("style");
            var left = style["left"];
            var top_1 = style["top"];
            var width = style["width"];
            var height = style["height"];
            this.canvasContext.clearRect(parseInt(left, 10), parseInt(top_1, 10), parseInt(width, 10), parseInt(height, 10));
            this.canvasContext.strokeRect(parseInt(left, 10), parseInt(top_1, 10), parseInt(width, 10), parseInt(height, 10));
            this.canvasContext.fillRect(parseInt(left, 10), parseInt(top_1, 10), parseInt(width, 10), parseInt(height, 10));
        }
    };
    /**
     * Remove image at given index.
     * @param index the index in screenshot array.
     */
    FeedbackScreenshotComponent.prototype.remove = function (index) {
        this.screenshots.splice(index, 1);
        this.changeDetection.detectChanges();
    };
    /**
     * Remove the mouse drawing events.
     */
    FeedbackScreenshotComponent.removeMouseDrawingEvents = function () {
        document.removeEventListener("mousedown");
        document.removeEventListener("mouseup");
        document.removeEventListener("mousemove");
    };
    /**
     * Setup mouse drawing events.
     */
    FeedbackScreenshotComponent.prototype.setupMouseDrawingEvents = function () {
        var _this = this;
        document.addEventListener("mousedown", function (event) {
            /* Make sure we don't execute when clicking on feedback buttons. */
            if (!event.target || !event.target.classList.contains(FEEDBACK_BTN_CLASS)) {
                _this.startDrawing(event.pageX, event.pageY);
            }
        });
        document.addEventListener("mouseup", function (event) {
            /* Make sure we don't execute when clicking on feedback buttons. */
            if (!event.target || !event.target.classList.contains(FEEDBACK_BTN_CLASS)) {
                _this.finishDrawing(event.pageX, event.pageY);
            }
        });
        document.addEventListener("mousemove", function (event) {
            _this.adjustDrawing(event.pageX, event.pageY);
        });
    };
    /**
     * Start drawing from given position.
     * @param x the x-axis page position to start at.
     * @param y the y-axis page position to start at.
     */
    FeedbackScreenshotComponent.prototype.startDrawing = function (x, y) {
        if (!this.canvasContext) {
            return;
        }
        this.centerX = x;
        this.centerY = y;
        this.canvasContext.beginPath();
        this.isDrawing = true;
        this.redraw();
    };
    /**
     * Capture a screenshot.
     */
    FeedbackScreenshotComponent.prototype.takeScreenshot = function () {
        var _this = this;
        this.preRenderScrollPosition = window.pageYOffset;
        document.body.scrollTop = 0; // Scroll to the top.
        document.body.style["overflow"] = "hidden"; // Disable Scroll.
        document.body.classList.add("wait"); // Set cursor for body to wait.
        this.canvas.classList.add("wait"); // Set cursor for canvas to wait.
        this.feedback.lockTakeScreenshotButtons();
        FeedbackScreenshotComponent.removeMouseDrawingEvents();
        var options = {
            onrendered: function (canvas) { return _this.processRenderedScreenshot(canvas); }
        };
        /* Create a canvas from body, and create an image out of it. */
        if (html2canvas) {
            html2canvas(document.body, options);
        }
        else {
            console.error("html2canvas not initialized. Please add it to your project or disable 'Take Screenshot' functionality.");
        }
    };
    return FeedbackScreenshotComponent;
}());
FeedbackScreenshotComponent.decorators = [
    { type: _angular_core.Component, args: [{
                selector: "ngx-bootstrap-feedback-screenshot",
                styles: ["\n    .feedback-screenshot img {\n      width: 100%;\n      border: 2px solid #EBEBEB;\n      border-radius: 12px;\n      object-fit: cover;\n    }\n  "],
                template: "<label *ngIf=\"!configuration.disableUpload\"\n       [attr.class]=\"configuration.uploadButtonClass ? configuration.uploadButtonClass : 'btn btn-primary btn-block'\"\n       [attr.disabled]=\"isMaxImageCountReached() ? true : null\">\n  <span class=\"glyphicon glyphicon-open\"></span>\n  {{configuration.uploadButtonText ? configuration.uploadButtonText : \"Upload\"}}\n  <input *ngIf=\"!isMaxImageCountReached()\" type=\"file\" style=\"display: none\" (change)=\"addScreenshot($event)\">\n</label>\n<p *ngIf=\"uploadErrorMessage\" [attr.class]=\"configuration.uploadErrorMessageClass ? configuration.uploadErrorMessageClass : 'text-danger'\">{{uploadErrorMessage}}</p>\n<button *ngIf=\"!configuration.disableScreenshotMode\"\n        [attr.class]=\"configuration.enterScreenshotModeButtonClass ? configuration.enterScreenshotModeButtonClass : 'btn btn-info btn-block'\"\n        [attr.disabled]=\"isMaxImageCountReached() ? true : null\"\n        type=\"button\" (click)=\"enterScreenshotMode()\">\n  <span class=\"glyphicon glyphicon-camera\" aria-hidden=\"true\"></span>\n  {{configuration.enterScreenshotModeButtonText ? configuration.enterScreenshotModeButtonText : \"Take Screenshot\"}}\n</button>\n<p *ngIf=\"isMaxImageCountReached()\"\n   [attr.class]=\"configuration.maxImageCountReachedErrorMessageClass ? configuration.maxImageCountReachedErrorMessageClass : 'text-warning'\">\n  {{configuration.maxImageCountReachedErrorMessageText ? configuration.maxImageCountReachedErrorMessageText : \"Image limit reached. Please remove some to add more.\"}}\n</p>\n<div *ngFor=\"let screenshot of screenshots; let id = index\" [attr.class]=\"configuration.screenshotEmbedClass ? configuration.screenshotEmbedClass : 'feedback-screenshot'\">\n  <button [attr.class]=\"configuration.screenshotEmbedRemoveButtonClass ? configuration.screenshotEmbedRemoveButtonClass : 'close'\"\n          data-dismiss=\"modal\" aria-label=\"Close\" type=\"button\"\n          (click)=\"remove(id)\">\n    <span aria-hidden=\"true\">&times;</span>\n  </button>\n  <img *ngIf=\"screenshot\" [src]=\"screenshot\" alt=\"{{id}}\"/>\n</div>\n\n",
            },] },
];
/** @nocollapse */
FeedbackScreenshotComponent.ctorParameters = function () { return [
    { type: _angular_core.ChangeDetectorRef, },
    { type: FeedbackService, },
]; };
FeedbackScreenshotComponent.propDecorators = {
    'configuration': [{ type: _angular_core.Input },],
};

var FeedbackModule = (function () {
    function FeedbackModule() {
    }
    return FeedbackModule;
}());
FeedbackModule.decorators = [
    { type: _angular_core.NgModule, args: [{
                declarations: [
                    FeedbackComponent,
                    FeedbackModalComponent,
                    FeedbackScreenshotComponent
                ],
                imports: [
                    _angular_common.CommonModule,
                    _herbis_ngxModal.ModalModule
                ],
                exports: [
                    FeedbackComponent,
                    FeedbackScreenshotComponent
                ],
                providers: [
                    FeedbackService
                ]
            },] },
];
/** @nocollapse */
FeedbackModule.ctorParameters = function () { return []; };

exports.FeedbackComponent = FeedbackComponent;
exports.FeedbackModule = FeedbackModule;
exports.FeedbackScreenshotComponent = FeedbackScreenshotComponent;
exports.FeedbackModel = FeedbackModel;

Object.defineProperty(exports, '__esModule', { value: true });

})));
