import { Component, Input, ViewChild } from "@angular/core";
import { FeedbackService } from "./feedback.service";
import { FeedbackModel } from "./feedback.model";
import { Modal } from "@herbis/ngx-modal";
var FeedbackModalComponent = (function () {
    function FeedbackModalComponent(feedback) {
        this.feedback = feedback;
        feedback.modalComponent = this;
    }
    /**
     * Cancel the feedback.
     */
    FeedbackModalComponent.prototype.cancel = function () {
        /* Callback on cancel.*/
        if (this.configuration.onCancel) {
            this.configuration.onCancel();
        }
        this.closeModal();
    };
    /**
     * Close this modal.
     */
    FeedbackModalComponent.prototype.closeModal = function () {
        this.modal.close();
        this.feedback.showSendFeedbackButton();
    };
    /**
     * Open feedback modal.
     */
    FeedbackModalComponent.prototype.openModal = function () {
        this.modal.open();
    };
    /**
     * Submit the form.
     * @param form the form.
     */
    FeedbackModalComponent.prototype.submit = function (form) {
        var feedbackSubmission = new FeedbackModel();
        feedbackSubmission.form = form;
        feedbackSubmission.screenshots = this.feedback.getScreenshots();
        /* Callback on submit validation */
        if (this.configuration.onSubmitValidation) {
            if (!this.configuration.onSubmitValidation(feedbackSubmission)) {
                return; // Do not proceed if validation unsuccessful.
            }
        }
        /* Callback on submit. */
        if (this.configuration.onSubmit) {
            this.configuration.onSubmit(feedbackSubmission);
            this.closeModal();
        }
        else {
            console.warn("No onSubmit callback function configured. It probably should.");
        }
    };
    return FeedbackModalComponent;
}());
export { FeedbackModalComponent };
FeedbackModalComponent.decorators = [
    { type: Component, args: [{
                selector: "ngx-bootstrap-feedback-modal",
                template: "<modal title=\"{{configuration.feedbackModalTitle ? configuration.feedbackModalTitle : 'Send Feedback'}}\"\n        modalClass=\"{{configuration.feedbackModalClass ? configuration.feedbackModalClass : 'modal-md'}}\"\n        [hideCloseButton]=\"true\"\n        [closeOnEscape]=\"false\"\n        [closeOnOutsideClick]=\"false\">\n  <modal-header></modal-header>\n  <modal-content>\n    <form novalidate #userFeedbackForm>\n      <ng-content></ng-content>\n    </form>\n  </modal-content>\n  <modal-footer>\n    <button [attr.class]=\"configuration.cancelFeedbackButtonClass ? configuration.cancelFeedbackButtonClass : 'btn btn-default'\" data-dismiss=\"modal\" type=\"button\" (click)=\"cancel()\">\n      {{configuration.cancelFeedbackButtonText ? configuration.cancelFeedbackButtonText : \"Cancel\"}}\n    </button>\n    <button [attr.class]=\"configuration.submitFeedbackButtonClass ? configuration.submitFeedbackButtonClass : 'btn btn-primary'\" type=\"button\" (click)=\"submit(userFeedbackForm)\">\n      {{configuration.submitFeedbackButtonText ? configuration.submitFeedbackButtonText : \"Submit\"}}\n    </button>\n  </modal-footer>\n</modal>\n"
            },] },
];
/** @nocollapse */
FeedbackModalComponent.ctorParameters = function () { return [
    { type: FeedbackService, },
]; };
FeedbackModalComponent.propDecorators = {
    'configuration': [{ type: Input },],
    'modal': [{ type: ViewChild, args: [Modal,] },],
};
//# sourceMappingURL=feedback-modal.component.js.map